// src/list-helpers.ts
function getListItemSpacing(tokenIndex, tokens) {
  const token = tokens[tokenIndex];
  if (!token || token.type !== "list_item_open") {
    return "thin";
  }
  let closeIndex = tokenIndex;
  const baseLevel = token.level;
  for (let i = tokenIndex + 1; i < tokens.length; i++) {
    if (tokens[i] && tokens[i]?.type === "list_item_close" && tokens[i]?.level === baseLevel) {
      closeIndex = i;
      break;
    }
  }
  const children = [];
  for (let i = tokenIndex + 1; i < closeIndex; i++) {
    if (tokens[i] && tokens[i]?.level === baseLevel + 1 && tokens[i]?.map && tokens[i]?.type.endsWith("_open")) {
      children.push(tokens[i]);
    }
  }
  if (children.length > 1) {
    return "thick";
  }
  if (children.length === 1 && token.map) {
    const child = children[0];
    if (!child) {
      return "thin";
    }
    if (!child.map) {
      return "thin";
    }
    const itemStart = token.map[0];
    const itemEnd = token.map[1];
    const childStart = child.map[0];
    const childEnd = child.map[1];
    let isFirst = true;
    let isLast = true;
    for (let i = tokenIndex - 1; i >= 0; i--) {
      const currentToken = tokens[i];
      if (currentToken && currentToken.type === "list_item_open" && currentToken.level === baseLevel) {
        isFirst = false;
        break;
      }
      if (currentToken && currentToken.level < baseLevel) break;
    }
    for (let i = closeIndex + 1; i < tokens.length; i++) {
      const currentToken = tokens[i];
      if (currentToken && currentToken.type === "list_item_open" && currentToken.level === baseLevel) {
        isLast = false;
        break;
      }
      if (currentToken && currentToken.level < baseLevel) break;
    }
    if (!isFirst && isLast) {
      if (childStart - itemStart >= 1) {
        return "thick";
      }
    } else if (isFirst && !isLast) {
      if (itemEnd - childEnd >= 1) {
        return "thick";
      }
    } else if (!isFirst && !isLast) {
      if (childStart - itemStart >= 1 || itemEnd - childEnd >= 1) {
        return "thick";
      }
    }
  }
  return "thin";
}
export {
  getListItemSpacing
};
